//
//  SDKAuthenticatorManger.swift
//  Zoom Remote macOS
//
//  Created by Satendra Dagar on 09/06/20.
//  Copyright © 2020 Thomas Miskiewicz. All rights reserved.
//

import Foundation
import ZoomSDK

class SDKAuthenticatorManger: NSObject {
    
    static let shared = SDKAuthenticatorManger()
    var token: JWTToken?
    
//    var retries = 1
    
    func checkAndAuthenticate(){
        if let token = token {
            if token.isExpired{
                authenticate()
            }
            else{
                print("Auth:::...Using valid token...")
            }
        }
        else{
            authenticate()
        }
    }
    
    func authenticate() -> Void {
        print("Auth:::...authenticating...")

        JWTTokenGenerator.refreshJWTToken { (token) in
            if let token = token{
                print("Auth:::...Received Token..\(token.token)")

                DispatchQueue.main.async {
                    print("Auth:::...ZoomServices initAndAuthZoomSDKWithJWT..\(token.token)")
                    let res = ZoomServices.initAndAuthZoomSDKWithJWT(token: token, delegate: self)
                    if res ==  true{

                        print("Auth:::...ZoomServices Successfully authenticated..\(token.token)")
                        
                        self.token = token
//                        self.login()
                    }
                    else{
                        
                    }
                }
            }
            else{
                
            }
        }
    }
    
    func login(userName:String, passord:String) -> Void {
        print("Login into account....")
//        let res = ZoomSDK.shared()?.getAuthService()?.login("satendradagar@gmail.com", password: "*******", rememberMe: false)
        let res = ZoomSDK.shared()?.getAuthService()?.login(userName , password: passord, rememberMe: false)
        print("Login Res:\(String(describing: res))")
        if res == ZoomSDKError_Success {
            print("Login was success")
        }
    }
    
    func logoutZoom() -> Void {
        ZoomSDK.shared()?.getAuthService()?.logout()
    }
    
    func showAuthFailError() -> Void {
        DispatchQueue.main.async {
            let alert: NSAlert = NSAlert()
            alert.messageText = "An unexpected error occured."
            alert.informativeText = "Please restart the app and if it’s still doens’t work write to hello@zoomremote.app"
            alert.alertStyle = NSAlert.Style.warning
            alert.addButton(withTitle: "Accept")
            alert.addButton(withTitle: "Cancel")
            let res = alert.runModal()
            
            if res == NSApplication.ModalResponse.alertFirstButtonReturn {
                NSApp.terminate(nil)
            }
            
        }
    }
}

extension SDKAuthenticatorManger : ZoomSDKAuthDelegate {
    func onZoomSDKAuthReturn(_ returnValue: ZoomSDKAuthError) {
        print("onMobileRTCAuthReturn \(returnValue)")
        if returnValue != ZoomSDKAuthError_Success{
            let message = NSLocalizedString("SDK authentication failed, error code: \(returnValue)", comment: "")
            print(message)
            print("Auth:::...Success")
        }
        else{
//            login()
            checkAndAuthenticate()

        }
    }
    
    func onZoomAuthIdentityExpired() {
        print("Auth:::...Expired Token")

        checkAndAuthenticate()

    }
    
    func onZoomSDKLogin(_ loginStatus: ZoomSDKLoginStatus, failReason reason: String?) {
        print("Login status:\(loginStatus), reason:\(reason)")
//        let userInfo = ZoomSDK.shared()?.getAuthService()?.getAccountInfo()
//        let type = "\(userInfo?.getSDKUserType().rawValue ?? 100)"
//        let dict = ZoomLoginFactory.loginResponseDict(loginStatus.zoomStatus, reason ?? "", displayName: userInfo?.getDisplayName() ?? "", userType: type)
//        BonjourServiceManager.shared.sendDict(dict: dict)
        sendLoginDetails(loginStatus: loginStatus, reason)
        if loginStatus == ZoomSDKLoginStatus_Success{
            if let premeetingService =  ZoomSDK.shared()?.getPremeetingService() {

            }

        }

    }

    func onZoomSDKLogout() {
        print("Login onZoomSDKLogout")
        sendLoginDetails(loginStatus: nil, "Logout")
    }

    func sendLoginDetails(loginStatus: ZoomSDKLoginStatus?, _ reason:String?) -> Void {
        
        let userInfo = ZoomSDK.shared()?.getAuthService()?.getAccountInfo()            
//        for item in meetings
        
//        print("Config:\(config)")
        let type = "\(userInfo?.getSDKUserType().rawValue ?? 100)"
//
    }
    
}

extension JWTToken{
    var isExpired: Bool {
        let timeStampNow = Date().timeIntervalSince1970
        if timeStampNow >= self.expires_at{
            return true
        }
        return false
    }
}
