//
//  JWTTokenGenerator.swift
//  Zoom Remote macOS
//
//  Created by Satendra Dagar on 09/06/20.
//  Copyright © 2020 Thomas Miskiewicz. All rights reserved.
//

import Foundation

class JWTTokenGenerator: NSObject {
    
    static func refreshJWTToken(completion: @escaping (JWTToken?) -> Void) -> Void {
       let communication = ApiCommunicator()
        communication.dataRequest(with: ServiceURLS.tokenService.rawValue, objectType: JWTToken.self){ (result: Result) in
            switch result {
            case .success(let object):
                completion(object)
                print(object)
            case .failure(let error):
                completion(nil)
                print(error)
            }
        }
    }
}

enum APPError: Error {
     case networkError(Error)
     case dataNotFound
     case jsonParsingError(Error)
     case invalidStatusCode(Int)
 }

 //Result enum to show success or failure
 enum Result<T> {
     case success(T)
     case failure(APPError)
 }

class ApiCommunicator: NSObject {
    //APPError enum which shows all possible errors
 

    //dataRequest which sends request to given URL and convert to Decodable Object
    func dataRequest<T: Decodable>(with url: String, objectType: T.Type, completion: @escaping (Result<T>) -> Void) {

        //create the url with NSURL
        let dataURL = URL(string: url)! //change the url

        //create the session object
        let session = URLSession.shared

        //now create the URLRequest object using the url object
        let request = URLRequest(url: dataURL, cachePolicy: .useProtocolCachePolicy, timeoutInterval: 60)

        //create dataTask using the session object to send data to the server
        let task = session.dataTask(with: request, completionHandler: { data, response, error in
            guard error == nil else {
                
                completion(Result.failure(APPError.networkError(error!)))
                return
            }

            guard let data = data else {
                completion(Result.failure(APPError.dataNotFound))
                return
            }
            print("response:\(String(describing: String(data: data, encoding: .utf8)))")

            do {
                //create decodable object from data
                let decodedObject = try JSONDecoder().decode(objectType.self, from: data)
                completion(Result.success(decodedObject))
            } catch let error {
                completion(Result.failure(APPError.jsonParsingError(error as! DecodingError)))
            }
        })

        task.resume()
    }
}
